@@ -5,8 +5,8 @@ use warnings;
 use 5.008001;
 use base qw( Alien::Base );
 
-# ABSTRACT: Find or download or build cmake 3 or better
-our $VERSION = '0.06'; # VERSION
+# ABSTRACT: Find or download or build cmake 3
+our $VERSION = '0.09'; # VERSION
 
 
 sub exe
@@ -37,11 +37,11 @@ __END__
 
 =head1 NAME
 
-Alien::cmake3 - Find or download or build cmake 3 or better
+Alien::cmake3 - Find or download or build cmake 3
 
 =head1 VERSION
 
-version 0.06
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ From L<alienfile>
 =head1 DESCRIPTION
 
 This L<Alien> distribution provides an external dependency on the build tool C<cmake>
-version 3.0.0 or better.  C<cmake> is a popular alternative to autoconf.
+version 3.x.x.  C<cmake> is a popular alternative to autoconf.
 
 =head1 METHODS
 
@@ -115,7 +115,7 @@ these ways:
 
 It integrates better with L<Alien>s that are based on that technology.
 
-=item L<Alien::cmake3> will provide version 3.0.0 or better
+=item L<Alien::cmake3> will provide version 3.x.x
 
 L<Alien::CMake> will provide 2.x.x on some platforms where more recent binaries are not available.
 
@@ -131,6 +131,56 @@ In the opinion of the maintainer of both L<Alien::cmake3> and L<Alien::CMake> fo
 
 =back
 
+=head1 ENVIRONMENT
+
+=over 4
+
+=item ALIEN_INSTALL_TYPE
+
+This is the normal L<Alien::Build> environment variable and you can set it to one of
+C<share>, C<system> or C<default>.
+
+=item ALIEN_CMAKE_FROM_SOURCE
+
+If set to true, and if a share install is attempted, L<Alien::cmake3> will not try a
+binary share install (even if available), and instead a source share install.
+
+=back
+
+=head1 CAVEATS
+
+If you do not have a system C<cmake> version 3.x.x available, then a share install
+will be attempted.
+
+Binary share installs are attempted on platforms for which the latest version of C<cmake>
+are provided.  As of this writing, this includes: Windows (32/64 bit), macOS
+(intel/arm universal) and Linux (intel/arm 64 bit).  No checks are made to ensure that
+your platform is supported by this binary installs.  Typically the same versions
+supported by the operating system vendor and supported by C<cmake>, so that should not
+be a problem.  If you are using an operating system not supported by its vendor
+Please Stop That, this is almost certainly a security vulnerability.
+
+That said if you really do need L<Alien::cmake3> on an unsupported system,
+you have some options:
+
+=over 4
+
+=item Install system version of C<cmake>
+
+If you can find an older version of C<cmake> 3.x.x that is supported by your operating
+system.
+
+=item Force a source code install
+
+Set the C<ALIEN_CMAKE_FROM_SOURCE> environment variable to a true value to build a
+share install from source.
+
+=back
+
+Source share installs are attempted on platforms for which the latest version of
+C<cmake> are not available, like the various flavours of *BSD.  This may not be ideal,
+and if you can install a system version of C<cmake> it may work better.
+
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
@@ -139,9 +189,11 @@ Contributors:
 
 Adriano Ferreira (FERREIRA)
 
+Dagfinn Ilmari Mannsåker (ilmari)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2024 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
